==> InfiniTec.Exchange_0.96_Source.zip: WebDav/Folder.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using InfiniTec.Threading;
using InfiniTec.Exchange.WebDav;
using InfiniTec.Exchange.Security;
using InfiniTec.Exchange.WebDav.Request;

namespace InfiniTec.Exchange.WebDav
{
    /// <summary>
    /// This class represents a public or private folder on an Exchange store.
    /// </summary>
    public class Folder: ItemBase
    {
        private bool _FolderNeedsCreation;

        /// <summary>
        /// True, if the folder is created when the <see cref="M:Folder.Save"/> 
        /// operation is called. False, otherwise.
        /// </summary>
        public bool FolderNeedsCreation
        {
            get { return _FolderNeedsCreation; }
        }

        /// <summary>
        /// Creates a new folder with the specified path.
        /// </summary>
        /// <param name="path">The path of the new folder.</param>
        /// <param name="connection">The <see cref="Connection"/> to use.</param>
        /// <returns>A <see cref="Folder"/> object</returns>
        public static Folder Create(string path, Connection connection)
        {
            return new Folder(path, connection, true);
        }

        /// <summary>
        /// Creates a new instance of this class using the specified
        /// path connection and (optional) properties.
        /// </summary>
        /// <param name="path">The path of the folder on the server.</param>
        /// <param name="connection">The <see cref="Connection"/> to use.</param>
        /// <param name="propertiesToLoad">The properties to retrieve. If omitted, all properties are retrieved.</param>
        public Folder(string path, Connection connection, params string[] propertiesToLoad):
            this(path, connection, false, propertiesToLoad)
        {
        }

        internal Folder(string path, Connection connection, bool isNew, params string[] propertiesToLoad):
            base(path, connection, propertiesToLoad)
        {
            _FolderNeedsCreation = isNew;
        }

        /// <summary>
        /// Returns the <see cref="FolderSecurity"/> of the folder.
        /// </summary>
        /// <returns>The security descriptor of the folder</returns>
        public FolderSecurity GetSecurity()
        {
            return GetSecurity<FolderSecurity>();
        }

        /// <summary>
        /// Replaces the current security descriptor with the specified one.
        /// </summary>
        /// <param name="security">The new security descriptor</param>
        public void SetSecurity(FolderSecurity security)
        {
            SetSecurityInternal((ExchangeSecurity) security);
        }
        /// <summary>
        /// Returns the save operation used to save the changes
        /// made to this instance.
        /// </summary>
        /// <returns></returns>
        public override AsyncOperation<RequestStatus> GetSaveOperation()
        {
            if (!FolderNeedsCreation) return base.GetSaveOperation();
            else return new AsyncOperation<RequestStatus>(SaveInternal());
        }

        private IEnumerable<OperationAction> SaveInternal()
        {
            using (AsyncOperation op = Methods.MkCol(Url, Properties))
            {
                yield return new NestedOperation(op, true);

                if (op.Status == OperationStatus.Completed) _FolderNeedsCreation = false;
            }
        }

        /// <summary>
        /// Returns a <see cref="Searcher"/> which can be used
        /// to search the current folder.
        /// </summary>
        /// <param name="propertiesToLoad">Optional. Specifies the
        /// properties to search for.</param>
        /// <returns>A <see cref="Searcher"/> instance.</returns>
        public Searcher Search(params string[] propertiesToLoad)
        {
            return new Searcher(Url, Connection, propertiesToLoad);
        }
    }
}

==> InfiniTec.Exchange_0.97_Source.zip: WebDav/Folder.cs <==
using System;
using System.Collections.Generic;
using System.Text;

namespace InfiniTec.Exchange.WebDav
{
    /// <summary>
    /// This class represents a public or private folder on an Exchange store.
    /// </summary>
    public class Folder: FolderBase
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Folder"/> class.
        /// </summary>
        /// <param name="path">The path of the folder on the server.</param>
        /// <param name="connection">The <see cref="Connection"/> to use.</param>
        /// <param name="propertiesToLoad">The properties to retrieve. If omitted, all properties are retrieved.</param>
        public Folder(string path, Connection connection, params string[] propertiesToLoad): 
            base(path, connection, propertiesToLoad) {}

        /// <summary>
        /// Initializes a new instance of the <see cref="Folder"/> class.
        /// </summary>
        /// <param name="path">The path.</param>
        /// <param name="connection">The connection.</param>
        /// <param name="isNew">if set to <c>true</c> [is new].</param>
        /// <param name="propertiesToLoad">The properties to load.</param>
        protected Folder(string path, Connection connection, bool isNew, params string[] propertiesToLoad):
            base(path, connection, isNew, propertiesToLoad) {}

        /// <summary>
        /// Returns a <see cref="Searcher"/> which can be used
        /// to search the current folder.
        /// </summary>
        /// <param name="propertiesToLoad">Optional. Specifies the
        /// properties to search for.</param>
        /// <returns>A <see cref="Searcher"/> instance.</returns>
        public Searcher Search(params string[] propertiesToLoad)
        {
            return new Searcher(Url, Connection, propertiesToLoad);
        }

        /// <summary>
        /// Creates a new folder with the specified path.
        /// </summary>
        /// <param name="path">The path of the new folder.</param>
        /// <param name="connection">The <see cref="Connection"/> to use.</param>
        /// <returns>A <see cref="Folder"/> object</returns>
        public static Folder Create(string path, Connection connection)
        {
            return new Folder(path, connection, true);
        }

    }
}
